@@ -1,21 +1,21 @@
 from functools import wraps
 
-import six
-
 from funk.error import FunkyError
 from funk.call import Call
 from funk.call import IntegerCallCount
 from funk.call import InfiniteCallCount
 from funk.sequence import Sequence
 from funk.util import function_call_str
+from . import pycompat
 
-__all__ = ['with_context', 'Context', 'expects', 'allows', 'set_attr', 'expects_call', 'allows_call']
+
+__all__ = ['with_mocks', 'Mocks', 'expects', 'allows', 'set_attr', 'expects_call', 'allows_call']
 
 class UnexpectedInvocationError(AssertionError):
     def __init__(self, mock_name, args, kwargs, expectations):
         args_str = map(repr, args)
         kwargs_str = {}
-        for key, value in six.iteritems(kwargs):
+        for key, value in pycompat.iteritems(kwargs):
             kwargs_str[key] = repr(value)
         call_str = function_call_str(mock_name, args_str, kwargs_str)
         exception_str = ["Unexpected invocation: %s" % call_str]
@@ -104,17 +104,17 @@ class MockedCallsForFunction(object):
         
         raise UnexpectedInvocationError(self._name, args, kwargs, desc)
 
-def with_context(test_function, mock_factory=None):
+def with_mocks(test_function, mock_factory=None):
     @wraps(test_function)
-    def test_function_with_context(*args, **kwargs):
-        if 'context' in kwargs:
-            raise FunkyError("context has already been set")
-        context = Context(mock_factory)
-        kwargs['context'] = context
+    def test_function_with_mocks(*args, **kwargs):
+        if 'mocks' in kwargs:
+            raise FunkyError("mocks has already been set")
+        mocks = Mocks(mock_factory)
+        kwargs['mocks'] = mocks
         test_function(*args, **kwargs)
-        context.verify()
+        mocks.verify()
     
-    return test_function_with_context
+    return test_function_with_mocks
 
 class MethodArgumentsSetter(object):
     def __init__(self, call):
@@ -154,7 +154,7 @@ def expects_call(mock):
 def allows_call(mock):
     return MethodArgumentsSetter(object.__getattribute__(mock, "_mocked_calls").add_function_call(InfiniteCallCount()))
 
-class Context(object):
+class Mocks(object):
     def __init__(self, mock_factory=None):
         if mock_factory is None:
             mock_factory = Mock
