@@ -1,6 +1,7 @@
 from funk.error import FunkyError
 from funk.util import function_call_str
 from funk.util import function_call_str_multiple_lines
+from funk.matchers import to_matcher
 from funk.matchers import Matcher
 from funk.matchers import equal_to
 
@@ -46,7 +47,7 @@ class Call(object):
         if not self._arguments_set:
             return True
             
-        def describe_arg((allowed, actual)):
+        def describe_arg(allowed, actual):
             desc = []
             if allowed.matches(actual, desc):
                 return "%s [matched]" % (allowed, )
@@ -56,11 +57,11 @@ class Call(object):
         def describe_kwargs(allowed_kwargs, actual_kwargs):
             kwargs_desc = {}
             for key in allowed_kwargs:
-                kwargs_desc[key] = describe_arg((allowed_kwargs[key], actual_kwargs[key]))
+                kwargs_desc[key] = describe_arg(allowed_kwargs[key], actual_kwargs[key])
             return kwargs_desc
         
         def describe_mismatch():
-            args_desc = map(describe_arg, zip(self._allowed_args, args))
+            args_desc = map(describe_arg, self._allowed_args, args)
             kwargs_desc = describe_kwargs(self._allowed_kwargs, kwargs)
             return function_call_str_multiple_lines(self._name, args_desc, kwargs_desc)
             
@@ -70,7 +71,7 @@ class Call(object):
             
         missing_kwargs = set(self._allowed_kwargs.keys()) - set(kwargs.keys())
         if len(missing_kwargs) > 0:
-            mismatch_description.append("%s [missing keyword arguments: %s]" % (str(self), ", ".join(missing_kwargs)))
+            mismatch_description.append("%s [missing keyword arguments: %s]" % (str(self), ", ".join(sorted(missing_kwargs))))
             return False
             
         extra_kwargs = set(kwargs.keys()) - set(self._allowed_kwargs.keys())
@@ -78,7 +79,7 @@ class Call(object):
             mismatch_description.append("%s [unexpected keyword arguments: %s]" % (str(self), ", ".join(extra_kwargs)))
             return False
             
-        if not all(map(lambda (matcher, arg): matcher.matches(arg, []), zip(self._allowed_args, args))):
+        if not all(map(lambda matcher, arg: matcher.matches(arg, []), self._allowed_args, args)):
             mismatch_description.append(describe_mismatch())
             return False
         
@@ -101,8 +102,8 @@ class Call(object):
     
     def with_args(self, *args, **kwargs):
         self._arguments_set = True
-        self._allowed_args = tuple(map(self._to_matcher, args))
-        self._allowed_kwargs = dict([(key, self._to_matcher(kwargs[key])) for key in kwargs])
+        self._allowed_args = tuple(map(to_matcher, args))
+        self._allowed_kwargs = dict([(key, to_matcher(kwargs[key])) for key in kwargs])
         return self
     
     def returns(self, return_value):
@@ -123,11 +124,6 @@ class Call(object):
     def is_satisfied(self):
         return self._call_count.is_satisfied()
 
-    def _to_matcher(self, value):
-        if isinstance(value, Matcher):
-            return value
-        return equal_to(value)
-
     def __str__(self):
         if self._arguments_set:
             return function_call_str(self._name, map(str, self._allowed_args), self._allowed_kwargs)
