@@ -1,10 +1,10 @@
-import six
+from . import pycompat
 
 
 def arguments_str(args, kwargs, separator=", "):
     args_strs = [str(arg) for arg in args]
     
-    sorted_kwargs = sorted(six.iteritems(kwargs), key=lambda x: x[0])
+    sorted_kwargs = sorted(pycompat.iteritems(kwargs), key=lambda x: x[0])
     kwargs_strs = ['%s=%s' % (key, value) for key, value in sorted_kwargs]
         
     all_args_strs = args_strs + kwargs_strs
